#
# spec file for package slrn
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           slrn
Version:        1.0.2
Release:        4.3
Summary:        Powerful, Threaded Newsreader
License:        GPL-2.0+
Group:          Productivity/Networking/News/Clients
Url:            http://www.slrn.org
## commented, cause previous files got deleted when new files are added
## hey, he call them snapshot versions
#Source:         http://www.jedsoft.org/slrn/download/slrn-%{version}.tar.gz
Source:         slrn-%{version}.tar.gz
# PATCH-FIX-OPENSUSE slrn-do-not-strip-binaries.diff gber@opensuse.org -- Prevents binaris from being stripped
Patch0:         slrn-do-not-strip-binaries.patch
# PATCH-FIX-UPSTREAM slrn-fix-libgnutls-extra-dependency.patch gber@opensuse.org -- Prevents unnecessary linking against libgnutls-extra
Patch1:         slrn-fix-libgnutls-extra-dependency.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  ed
BuildRequires:  mininews
BuildRequires:  slang-devel
# SSL support via GnuTLS does not work on openSUSE <= 12.1
%if 0%{?suse_version} > 1210
BuildRequires:  libgcrypt-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libgnutls-openssl-devel
%endif
# some slrn macros depend on certain slang modules
Recommends:     slang-slsh
Recommends:     %{name}-lang = %{version}

%description
slrn is a powerful, easy to use, and threaded Internet newsreader. It
is highly customizable, permitting redefinition of keys and including a
sophisticated macro language for further customization.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1

# correct path to sendmail
ed -s src/slrnfeat.hin 2>/dev/null <<'EOF'
,s/\/usr\/lib\/sendmail/\/usr\/sbin\/sendmail/
EOF

# replace __DATE__ and __TIME__ with date/time of the last specfile changelog
# entry
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{_sourcedir}/%{name}.changes")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find .  -name '*.[ch]' -print -exec sh -c '
    sed "/^[ \t]*#[ \t]*if/n;s/__DATE__/$3/g;s/__TIME__/$2/g" "$1" >"$1.new" && \
        mv "$1.new" "$1"
' {} {} "${TIME}" "${DATE}" \;

%build
autoconf -f -I ./autoconf -o configure autoconf/configure.ac
%configure \
    --with-slrnpull \
    --enable-inews \
%if 0%{?suse_version} > 1210
    --with-gnutls=%{_prefix} \
%endif
    --disable-rpath
make

%install
%make_install
install -m 644 -D doc/slrn.rc %{buildroot}%{_sysconfdir}/slrn/slrn.rc

# remove installed documentation, packaged manually below
rm -rf %{buildroot}%{_datadir}/doc

%find_lang %{name}

# make contrib scripts non-executable
find contrib/ doc -type f -exec chmod 644 {} +

%clean
rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%doc changes.txt COPYING COPYRIGHT README
%doc doc/{FAQ,FIRST_STEPS,help.txt,manual.txt,pc-keys.txt,README.GroupLens}
%doc doc/{README.macros,README.multiuser,README.SSL,score.txt,slrn-doc.html}
%doc doc/{slrnfuns.txt,slrn.rc,THANKS,*.sl}
%doc doc/slrnpull/ contrib/
%dir %{_sysconfdir}/slrn
%config(noreplace) %{_sysconfdir}/slrn/slrn.rc
%{_bindir}/slrn
%{_bindir}/slrnpull
%doc %{_mandir}/man1/slrn.1*
%doc %{_mandir}/man1/slrnpull.1*
%{_datadir}/slrn

%files lang -f %{name}.lang

%changelog
* Fri Jan 23 2015 sfalken@opensuse.org
- Update to version 1.0.2
  + src/misc.c: slrn_verror needed va_copy when writing to the log
    file.
  + src/post.c: Move the cursor to the end of the line when
    querying for a postpone filename.
  + Added support for building slrnpull on win32.
  + Made a note in the install files that slang+modules+slsh need
    to be installed.
  + macros/mime.sl: mime_process_multipart added to the
    read_article_hook.
  + Updated the FSF address
  + src/interp.c: The MAKE_INTRINSIC specification for the
    get_charset intrinsic wrapper function was incorrect leading
    to a SegV.
  + src/interp.c: Fixed a memory leak in the article_as_string
    functions.
  + configure: Parse /etc/ld.so.conf to look for additional lib
    paths
  + contrib/cleanscore: Fix perl prototypes
  + macros/multipart.sl: Fixed usage of the string_match return value.
  + src/mime.c: Do not mime-encode the In-Reply-To header.
  + src/sltcp.c: Set the gnutls global log level to 0 as a
    work-around for a connection issue when a higher value
    is used. (deb#728189>
  + src/interp.c: If get_header_flags is called with an optional
    non-zero integer argument, then it will return the full set of
    header flags associated with the current header.  Symbolic
    constants that correspond to these flags were also added to the
    interpreter interface.
  + po/Makefile.in.in, src/Makefile.in: Ignore install error when GNU
    msgfmt is not installed.
  + src/Makefile.in: Add support for CPPFLAGS
  + autoconf/configure.ac: Updated libs for current gnutls
  + src/group.c: Updated default value of query_read_group_cutoff to
    1000 to reflect faster networks.
  + doc/score.txt: Added a note about where to find the documentation
    for the slang regular expressions
  + src/slrn.c: Added support for SIGQUIT (deb#673529)
  + src/ttymsg.c: Strip \001 highlight characters from messages
    written to the terminal when not in fullscreen mode (deb#631021).
  + src/*.c,*.h: Updated copyright year for upcoming release.
  + NEWS file added with release notes.
  + autoconf/: updated configure scripts
  + src/Makefile.in: slang 2.2.3 or greater now required.
  + po/Makefile.in.in: Do not remove .gmo files if msgmerge is not
    installed.
- Added:
  + slrn-1.0.2.tar.gz
* Sat Dec 22 2012 gber@opensuse.org
- update to version 1.0.1
  - macros/mime.sl: Add an option to view all parts of a mime
    multipart message
  - src/art_misc.c: New config variable: "wrap_width", which sets the
    width that will trigger wrapping
  - doc/: Updated txt docs from slrn doc project's svn repos
  - An issue with the wrap_width variable was fixed
* Fri May 25 2012 gber@opensuse.org
- recommend slang-slsh since some slrn macros depend on certain
  slang modules
* Mon May 21 2012 gber@opensuse.org
- fixed dependency on libgnutls
- added slrn-fix-libgnutls-extra-dependency.patch which prevents
  unnecessary linking against libgnutls-extra and fixes the build
  in Factory
* Sun May  6 2012 chris@computersalat.de
- update to version pre1.0.0-40
  * Parse mime sub-keywords without regard to case
* Mon Apr  9 2012 gber@opensuse.org
- update to version pre1.0.0~39
  - bugfixes
  - support for multipart mime messages
- compile without -fno-strict-aliasing
- enable SSL support via GnuTLS which seems to work on
  openSUSE > 12.1
- drop superfluous patch slrn-0.9.9p1.diff
- drop slrn-0.9.9p1-hardcode-inews-path.diff and add a build
  dependency on mininews instead, this also makes
  slrn-0.9.9p1-configure.diff unecessary
- rebased slrn-0.9.9p1-do-not-strip-binaries.diff and renamed to
  slrn-do-not-strip-binaries.patch
- removed slrn.run, there is no SUSE menu any more
- removed obsolete slrn.rc migration pre-script
- replace __DATE__ and __TIME__ with date/time of latest changelog
  entry
- do not replace slrn.rc
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Sun Aug 22 2010 gber@opensuse.org
- update to version pre1.0.0~18
  * bugfixes mainly regarding MIME and charset handling
  * impoved output for --debug
- dropped obsolete slrn-0.9.9p1-fix-bufferoverflow.diff patch
- disabled SSL support by default until upstream gets around to
  making it work reliably
* Wed Apr 21 2010 guido+opensuse.org@berhoerster.name
- do not strip binaries
- fix rpmlint warnings
  * split off -lang subpackage
  * recompress source
- further cleanup
* Sun Dec 27 2009 guido+opensuse.org@berhoerster.name
- corrected licence information
* Sat Dec 26 2009 guido+opensuse.org@berhoerster.name
- enable SSL support
- drop unnecessary build dependencies
* Sat Dec 26 2009 guido+opensuse.org@berhoerster.name
- updated to 0.9.9p1:
  * many bugfixes
- dropped fromsearch patch which has been integrated upstream
- rebased other patches
- added fix for buffer overflow in src/art.c
* Mon Jun 30 2008 schwab@suse.de
- Work around autoconf limitation.
* Mon Feb 25 2008 crrodriguez@suse.de
- fix file-not-in-lang errors
* Tue Nov 14 2006 prusnak@suse.cz
- fixed author search (fromsearch.diff) [#202560]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 nadvornik@suse.cz
- updated to 0.9.8.1pl1:
  * slang2 support
* Fri Apr  2 2004 nadvornik@suse.cz
- do not send 8859-1 characters to UTF-8 slang [#37854]
* Thu Mar 25 2004 mmj@suse.de
- Invoke autoreconf to fix /usr/sbin/sendmail detection
- Add postfix to #neededforbuild
* Fri Feb 20 2004 mmj@suse.de
- Update to 0.9.8.0
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Aug 19 2002 mmj@suse.de
- Correct PreReq
* Wed Jun  5 2002 ro@suse.de
- specify slang library location for configure
* Fri May 31 2002 ro@suse.de
- changed neededforbuild <slang> to <slang slang-devel>
* Fri Nov 30 2001 nadvornik@suse.cz
- update to 0.9.7.3:
  - gettext is used, support for da, de, it, nl, pl, ru
  - minor UI changes, bugfixes
* Fri Jun 29 2001 nadvornik@suse.cz
- update to 0.9.7.1
- added script for SuSE menu [bug #8128]
* Fri Nov 10 2000 nadvornik@suse.cz
- update to 0.9.6.3
* Mon Oct  9 2000 nadvornik@suse.cz
- fixed Copyright
- used bzip2
* Thu Jul 27 2000 bjacke@suse.de
- added UTF8 reading support
* Mon May 22 2000 nadvornik@suse.cz
- used %%{_defaultdocdir}
* Thu May 18 2000 nadvornik@suse.cz
- changed Group tag
* Fri Mar 24 2000 nadvornik@suse.cz
- added URL
* Mon Mar 13 2000 @suse.cz
- upgrade to 0.9.6.2
- added BuildRoot
- removed Makefile.Linux
* Fri Mar  3 2000 fehr@suse.de
- move man pages to /usr/share/man
* Tue Jan  4 2000 fehr@suse.de
- fix y2k problem in NEWGROUPS command
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 27 1999 fehr@suse.de
- update to 0.9.5.7
* Thu Jul 16 1998 florian@suse.de
- simplified spec-file
- update to 0.9.5.2
* Wed Dec  3 1997 bs@suse.de
- added exit 0 to %%pre
* Thu Nov 27 1997 florian@suse.de
- update to 0.9.4.3
* Wed Nov 19 1997 florian@suse.de
- move config files to /var/lib/slrn
- add bug-fix to slrn
* Sun Apr 13 1997 florian@suse.de
- update to new version 0.9.3.2
* Thu Jan  2 1997 florian@suse.de
- update to new version 0.9.1.1
  Mon Sep  2 03:06:07 MET DST 1996
  "set group_dsc_start_column" fix.
